@@ -4,17 +4,10 @@ use std::sync::mpsc::Sender;
 use super::super::ws_client_internal::WSClientInternal;
 use super::super::{Candlestick, Level3OrderBook, OrderBook, OrderBookTopK, Ticker, Trade, BBO};
 use super::utils::{
-    channels_to_commands, fetch_ws_token, on_misc_msg, to_raw_channel, WebsocketToken,
+    channels_to_commands, fetch_ws_token, on_misc_msg, to_raw_channel,
     CLIENT_PING_INTERVAL_AND_MSG, EXCHANGE_NAME,
 };
 
-use lazy_static::lazy_static;
-
-lazy_static! {
-    static ref WS_TOKEN: WebsocketToken = fetch_ws_token();
-    static ref WEBSOCKET_URL: String = format!("{}?token={}", WS_TOKEN.endpoint, WS_TOKEN.token);
-}
-
 /// The WebSocket client for KuCoin Spot market.
 ///
 /// * WebSocket API doc: <https://docs.kucoin.com/#websocket-feed>
@@ -23,6 +16,37 @@ pub struct KuCoinSpotWSClient {
     client: WSClientInternal,
 }
 
+impl KuCoinSpotWSClient {
+    /// Creates a KuCoinSpotWSClient websocket client.
+    ///
+    /// # Arguments
+    ///
+    /// * `tx` - The sending part of a channel
+    /// * `url` - Optional server url, usually you don't need specify it
+    pub fn new(tx: Sender<String>, url: Option<&str>) -> Self {
+        let real_url = match url {
+            Some(endpoint) => endpoint.to_string(),
+            None => {
+                let ws_token = fetch_ws_token();
+                let ws_url = format!("{}?token={}", ws_token.endpoint, ws_token.token);
+                ws_url
+            }
+        };
+        println!("{}", real_url);
+        KuCoinSpotWSClient {
+            client: WSClientInternal::new(
+                EXCHANGE_NAME,
+                &real_url,
+                tx,
+                on_misc_msg,
+                channels_to_commands,
+                Some(CLIENT_PING_INTERVAL_AND_MSG),
+                None,
+            ),
+        }
+    }
+}
+
 #[rustfmt::skip]
 impl_trait!(Trade, KuCoinSpotWSClient, subscribe_trade, "/market/match", to_raw_channel);
 #[rustfmt::skip]
@@ -71,13 +95,4 @@ impl Level3OrderBook for KuCoinSpotWSClient {
     }
 }
 
-impl_new_constructor!(
-    KuCoinSpotWSClient,
-    EXCHANGE_NAME,
-    WEBSOCKET_URL.as_str(),
-    channels_to_commands,
-    on_misc_msg,
-    Some(CLIENT_PING_INTERVAL_AND_MSG),
-    None
-);
 impl_ws_client_trait!(KuCoinSpotWSClient);
